# Rustic AI Chroma

This module provides a [Chroma](https://docs.trychroma.com/docs/overview/introduction) implementation of [Rustic AI](https://www.rustic.ai/)'s vectorstore.

## Installing

```shell
pip install rusticai-chroma
```
**Note:** It depends on [rusticai-core](https://pypi.org/project/rusticai-core/)

## Building from Source

```shell
poetry install --with dev
poetry build
```